==> ci-hotel_V0.8.1_20100926.zip: ci-hotel_V0.8.1_20100926/system/application/views/res/index.php <==
<?php
include(dirname(__FILE__) . '/../header.php');
?>

<h2>宿泊内容入力</h2>

<?php echo validation_errors(); ?>

<?php
if (isset($error) && count($error)) { foreach ($error as $err) { echo $err . "<br />"; } }
?>

<?php echo form_open('res/index/' . $planid . '/' . $d); ?>

<table border="1px" width="100%">
<tr>
<td>プラン</td>
<td><?php echo $planid . ":" . $plan_name; ?></td>
</tr>
<tr>
<td>チェックイン日</td>
<td>
<?php
$s_cin = substr($d, 0, 4) . '-' . substr($d, 4, 2) . '-' . substr($d, 6, 2);
echo $s_cin;
echo ' (' . $this->Common_model->week($s_cin) . ')';
?></td>
</tr>
<tr>
<td>チェックアウト日</td>
<td><input type="text" name="cout" value="<?php echo set_value('cout', isset($cout) ? $cout : ''); ?>" size="20" /></td>
</tr>
<tr>
<td>部屋数</td>
<td><input type="text" name="room_num" value="<?php echo set_value('room_num', isset($room_num) ? $room_num : ''); ?>" size="4" /></td>
</tr>
<tr>
<td>1部屋あたりの人数</td>
<td>
大人:<input type="text" name="basic_num" value="<?php echo set_value('basic_num', isset($basic_num) ? $basic_num : ''); ?>" size="4" /> 
子供1:<input type="text" name="child1_num" value="<?php echo set_value('child1_num', isset($child1_num) ? $child1_num : ''); ?>" size="4" />
子供2:<input type="text" name="child2_num" value="<?php echo set_value('child2_num', isset($child2_num) ? $child2_num : ''); ?>" size="4" />
子供3:<input type="text" name="child3_num" value="<?php echo set_value('child3_num', isset($child3_num) ? $child3_num : ''); ?>" size="4" />
子供4:<input type="text" name="child4_num" value="<?php echo set_value('child4_num', isset($child4_num) ? $child4_num : ''); ?>" size="4" />
</td>
</tr>
</table>
<input type="submit" name="mysubmit" value="見積もりへ進む" />

</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>

==> ci-hotel_V0.9.2_20101011.zip: ci-hotel_V0.9.2_20101011/system/application/views/res/index.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<link rel="stylesheet" href="<?php echo base_url() ?>js/jquery/themes/base/jquery.ui.all.css">
<script src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.core.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.widget.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.datepicker.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/i18n/jquery.ui.datepicker-ja.js"></script>
	<script>
	$(function() {
		$("#datepicker").datepicker({dateFormat: 'yy-mm-dd'});
	});
	</script>
<?php
include(dirname(__FILE__) . '/../header2.php');
?>

<h2>宿泊内容入力</h2>

<?php echo validation_errors(); ?>

<?php
if (isset($error) && count($error)) { foreach ($error as $err) { echo $err . "<br />"; } }
?>

<?php echo form_open('res/index/' . $planid . '/' . $d); ?>

<table border="1px" width="100%">
<tr>
<td>プラン</td>
<td><?php echo $planid . ":" . $plan_name; ?></td>
</tr>
<tr>
<td>チェックイン日</td>
<td>
<?php
$s_cin = substr($d, 0, 4) . '-' . substr($d, 4, 2) . '-' . substr($d, 6, 2);
echo $s_cin;
echo ' (' . $this->Common_model->week($s_cin) . ')';
?></td>
</tr>
<tr>
<td>チェックアウト日</td>
<td><input type="text" name="cout" id="datepicker" value="<?php echo set_value('cout', isset($cout) ? $cout : ''); ?>" size="30" /></td>
</tr>
<tr>
<td>部屋数</td>
<td><input type="text" name="room_num" value="<?php echo set_value('room_num', isset($room_num) ? $room_num : ''); ?>" size="4" /></td>
</tr>
<tr>
<td>1部屋あたりの人数</td>
<td>
大人:<input type="text" name="basic_num" value="<?php echo set_value('basic_num', isset($basic_num) ? $basic_num : ''); ?>" size="4" /> 
子供1:<input type="text" name="child1_num" value="<?php echo set_value('child1_num', isset($child1_num) ? $child1_num : ''); ?>" size="4" />
子供2:<input type="text" name="child2_num" value="<?php echo set_value('child2_num', isset($child2_num) ? $child2_num : ''); ?>" size="4" />
子供3:<input type="text" name="child3_num" value="<?php echo set_value('child3_num', isset($child3_num) ? $child3_num : ''); ?>" size="4" />
子供4:<input type="text" name="child4_num" value="<?php echo set_value('child4_num', isset($child4_num) ? $child4_num : ''); ?>" size="4" />
</td>
</tr>
</table>
<input type="submit" name="mysubmit" value="見積もりへ進む" />

</form>

<image src="<?php echo site_url('images/step1.png') ?>">

<?php
include(dirname(__FILE__) . '/../footer.php');
?>
